#' @import methods
#' @import DBI
#' @import utils
#' @importFrom stats as.formula coefficients gaussian na.fail na.omit predict quantile
#' @importFrom dplyr type_sum
#' @importFrom rlang %||%
NULL

#' @importFrom generics tidy
#' @export
generics::tidy

#' @importFrom generics augment
#' @export
generics::augment

#' @importFrom generics glance
#' @export
generics::glance

#' @import forge
NULL

#' @importFrom ellipsis check_dots_used
NULL
